RefNum

Trait RefNum 

pub trait RefNum<Base>: NumOps<Base, Base> + for<'r> NumOps<&'r Base, Base> { }
The trait for Num references which implement numeric operations, taking the second operand either by value or by reference.

This is automatically implemented for all types which implement the operators. It covers every type implementing the operations though, regardless of it being a reference or related to Num.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T, Base> RefNum<Base> for T
where T: NumOps<Base, Base> + for<'r> NumOps<&'r Base, Base>,