pub trait Saturating {
// Required methods
fn saturating_add(self, v: Self) -> Self;
fn saturating_sub(self, v: Self) -> Self;
}Expand description
Saturating math operations. Deprecated, use SaturatingAdd, SaturatingSub and
SaturatingMul instead.
Required Methods
Sourcefn saturating_add(self, v: Self) -> Self
fn saturating_add(self, v: Self) -> Self
Saturating addition operator. Returns a+b, saturating at the numeric bounds instead of overflowing.
Sourcefn saturating_sub(self, v: Self) -> Self
fn saturating_sub(self, v: Self) -> Self
Saturating subtraction operator. Returns a-b, saturating at the numeric bounds instead of overflowing.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".