pub trait AsForeignNonCanonicalInterface<T>: Copywhere
T: Copy,{
// Required method
fn clone_as_foreign(&self) -> T;
}Expand description
Trait to interpret non-canonical math data structures of other math libs as their analogs a math lib of choice to use operations of the library..
Required Methods
Sourcefn clone_as_foreign(&self) -> T
fn clone_as_foreign(&self) -> T
Clone this data structure as analog of a math lib of choice to use its operations.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".