Module abs

Module abs 

Abstractions.

Modules

as_foreign
Interfaces to either conver or reinterpret nath data structure as analog of math lib of choice..
exposed
Exposed namespace of the module.
from
Local implementation of traits From / Into. Required because of limmitations of Rust.
nan_like
Define several traits like NanLikeInterface.
orphan
Orphan namespace of the module.
prelude
Prelude to use essentials: use my_module::prelude::*.
protected
Protected namespace of the module.
x2_interface
X2 interfaces.

Traits

AsForeignCanonicalInterface
Trait to interpret canonical math data structures of other math libs as their analogs a math lib of choice to use operations of the library..
AsForeignNonCanonicalInterface
Trait to interpret non-canonical math data structures of other math libs as their analogs a math lib of choice to use operations of the library..
From2
Local implementation of trait From.
Into2
Local implementation of trait Into.
NanLikeInterface
Implement check is it nan and constructor with NAN value.
X2BasicInterface
Standard interface of vector X2. Implements nominal interface, extending it by constructor make.
X2CanonicalInterface
Interface of vector X2 for structures with the canonical layout.
X2Interface
Nominal interface of vector X2.
X2NominalInterface
Nominal interface of vector X2.