Module as_foreign

Module as_foreign 

Interfaces to either conver or reinterpret nath data structure as analog of math lib of choice..

Modules

exposed
Exposed namespace of the module.
orphan
Orphan namespace of the module.
prelude
Prelude to use essentials: use my_module::prelude::*.
protected
Protected namespace of the module.

Traits

AsForeignCanonicalInterface
Trait to interpret canonical math data structures of other math libs as their analogs a math lib of choice to use operations of the library..
AsForeignNonCanonicalInterface
Trait to interpret non-canonical math data structures of other math libs as their analogs a math lib of choice to use operations of the library..