pub trait AsForeignCanonicalInterface<T>: AsForeignNonCanonicalInterface<T> + Copywhere
T: Copy,{
// Required methods
fn as_foreign(&self) -> &T;
fn as_foreign_mut(&mut self) -> &mut T;
}Expand description
Trait to interpret canonical math data structures of other math libs as their analogs a math lib of choice to use operations of the library..
Required Methods
Sourcefn as_foreign(&self) -> &T
fn as_foreign(&self) -> &T
Interpret this data structure as analog of a math lib of choice to use its operations.
Sourcefn as_foreign_mut(&mut self) -> &mut T
fn as_foreign_mut(&mut self) -> &mut T
Interpret this data structure mutably as analog of a math lib of choice to use its operations.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".