pub trait NumAssignOps<Rhs = Self>:
AddAssign<Rhs>
+ SubAssign<Rhs>
+ MulAssign<Rhs>
+ DivAssign<Rhs>
+ RemAssign<Rhs> { }Expand description
Generic trait for types implementing numeric assignment operators (like +=).
This is automatically implemented for types which implement the operators.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".